#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"
#include <stdint.h>

#line 4 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer config_doxywYY_create_buffer
#define yy_delete_buffer config_doxywYY_delete_buffer
#define yy_scan_buffer config_doxywYY_scan_buffer
#define yy_scan_string config_doxywYY_scan_string
#define yy_scan_bytes config_doxywYY_scan_bytes
#define yy_init_buffer config_doxywYY_init_buffer
#define yy_flush_buffer config_doxywYY_flush_buffer
#define yy_load_buffer_state config_doxywYY_load_buffer_state
#define yy_switch_to_buffer config_doxywYY_switch_to_buffer
#define yypush_buffer_state config_doxywYYpush_buffer_state
#define yypop_buffer_state config_doxywYYpop_buffer_state
#define yyensure_buffer_stack config_doxywYYensure_buffer_stack
#define yy_flex_debug config_doxywYY_flex_debug
#define yyin config_doxywYYin
#define yyleng config_doxywYYleng
#define yylex config_doxywYYlex
#define yylineno config_doxywYYlineno
#define yyout config_doxywYYout
#define yyrestart config_doxywYYrestart
#define yytext config_doxywYYtext
#define yywrap config_doxywYYwrap
#define yyalloc config_doxywYYalloc
#define yyrealloc config_doxywYYrealloc
#define yyfree config_doxywYYfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define config_doxywYY_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer config_doxywYY_create_buffer
#endif

#ifdef yy_delete_buffer
#define config_doxywYY_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer config_doxywYY_delete_buffer
#endif

#ifdef yy_scan_buffer
#define config_doxywYY_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer config_doxywYY_scan_buffer
#endif

#ifdef yy_scan_string
#define config_doxywYY_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string config_doxywYY_scan_string
#endif

#ifdef yy_scan_bytes
#define config_doxywYY_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes config_doxywYY_scan_bytes
#endif

#ifdef yy_init_buffer
#define config_doxywYY_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer config_doxywYY_init_buffer
#endif

#ifdef yy_flush_buffer
#define config_doxywYY_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer config_doxywYY_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define config_doxywYY_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state config_doxywYY_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define config_doxywYY_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer config_doxywYY_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define config_doxywYYpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state config_doxywYYpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define config_doxywYYpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state config_doxywYYpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define config_doxywYYensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack config_doxywYYensure_buffer_stack
#endif

#ifdef yylex
#define config_doxywYYlex_ALREADY_DEFINED
#else
#define yylex config_doxywYYlex
#endif

#ifdef yyrestart
#define config_doxywYYrestart_ALREADY_DEFINED
#else
#define yyrestart config_doxywYYrestart
#endif

#ifdef yylex_init
#define config_doxywYYlex_init_ALREADY_DEFINED
#else
#define yylex_init config_doxywYYlex_init
#endif

#ifdef yylex_init_extra
#define config_doxywYYlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra config_doxywYYlex_init_extra
#endif

#ifdef yylex_destroy
#define config_doxywYYlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy config_doxywYYlex_destroy
#endif

#ifdef yyget_debug
#define config_doxywYYget_debug_ALREADY_DEFINED
#else
#define yyget_debug config_doxywYYget_debug
#endif

#ifdef yyset_debug
#define config_doxywYYset_debug_ALREADY_DEFINED
#else
#define yyset_debug config_doxywYYset_debug
#endif

#ifdef yyget_extra
#define config_doxywYYget_extra_ALREADY_DEFINED
#else
#define yyget_extra config_doxywYYget_extra
#endif

#ifdef yyset_extra
#define config_doxywYYset_extra_ALREADY_DEFINED
#else
#define yyset_extra config_doxywYYset_extra
#endif

#ifdef yyget_in
#define config_doxywYYget_in_ALREADY_DEFINED
#else
#define yyget_in config_doxywYYget_in
#endif

#ifdef yyset_in
#define config_doxywYYset_in_ALREADY_DEFINED
#else
#define yyset_in config_doxywYYset_in
#endif

#ifdef yyget_out
#define config_doxywYYget_out_ALREADY_DEFINED
#else
#define yyget_out config_doxywYYget_out
#endif

#ifdef yyset_out
#define config_doxywYYset_out_ALREADY_DEFINED
#else
#define yyset_out config_doxywYYset_out
#endif

#ifdef yyget_leng
#define config_doxywYYget_leng_ALREADY_DEFINED
#else
#define yyget_leng config_doxywYYget_leng
#endif

#ifdef yyget_text
#define config_doxywYYget_text_ALREADY_DEFINED
#else
#define yyget_text config_doxywYYget_text
#endif

#ifdef yyget_lineno
#define config_doxywYYget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno config_doxywYYget_lineno
#endif

#ifdef yyset_lineno
#define config_doxywYYset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno config_doxywYYset_lineno
#endif

#ifdef yywrap
#define config_doxywYYwrap_ALREADY_DEFINED
#else
#define yywrap config_doxywYYwrap
#endif

#ifdef yyalloc
#define config_doxywYYalloc_ALREADY_DEFINED
#else
#define yyalloc config_doxywYYalloc
#endif

#ifdef yyrealloc
#define config_doxywYYrealloc_ALREADY_DEFINED
#else
#define yyrealloc config_doxywYYrealloc
#endif

#ifdef yyfree
#define config_doxywYYfree_ALREADY_DEFINED
#else
#define yyfree config_doxywYYfree
#endif

#ifdef yytext
#define config_doxywYYtext_ALREADY_DEFINED
#else
#define yytext config_doxywYYtext
#endif

#ifdef yyleng
#define config_doxywYYleng_ALREADY_DEFINED
#else
#define yyleng config_doxywYYleng
#endif

#ifdef yyin
#define config_doxywYYin_ALREADY_DEFINED
#else
#define yyin config_doxywYYin
#endif

#ifdef yyout
#define config_doxywYYout_ALREADY_DEFINED
#else
#define yyout config_doxywYYout
#endif

#ifdef yy_flex_debug
#define config_doxywYY_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug config_doxywYY_flex_debug
#endif

#ifdef yylineno
#define config_doxywYYlineno_ALREADY_DEFINED
#else
#define yylineno config_doxywYYlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define config_doxywYYwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 25
#define YY_END_OF_BUFFER 26
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[96] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   26,   24,   22,   23,   24,   24,   24,    8,
       24,    8,   20,   20,   17,   19,   20,   12,   12,    9,
       11,   12,   16,   16,   13,   15,   16,    7,   24,    7,
        7,    0,   21,    0,    0,    2,    8,    0,    0,    0,
        8,    3,   20,    0,   18,   20,   12,    0,   10,   12,
       16,    0,   14,   16,    7,    0,    7,    0,    0,    4,
       20,   12,   16,    7,    7,    1,    0,    1,    1,    1,
        1,    0,    0,    0,    0,    0,    6,    0,    0,    0,
        0,    0,    0,    5,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    1,    7,    1,    1,    1,    1,    8,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    1,    1,    1,
       10,    1,    1,   11,   12,   13,   14,   15,   16,   13,
       13,   17,   18,   13,   13,   19,   13,   20,   13,   21,
       13,   13,   13,   22,   23,   13,   13,   13,   13,   13,
        1,   24,    1,    1,   25,    1,   13,   13,   13,   26,

       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   27,
       13,   13,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[29] =
    {   0,
        1,    2,    3,    4,    5,    1,    6,    7,    7,    6,
        1,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    8,    7,    7,    7,    1
    } ;

static const flex_int16_t yy_base[109] =
    {   0,
        0,   27,   55,    0,   82,  109,  136,  163,  190,  217,
      244,  271,  125,  391,  391,  391,    3,   97,  120,    0,
      104,    6,    0,    0,  391,    7,   94,    0,    0,  391,
       15,   93,    0,    0,  391,   18,   92,    0,    0,   23,
       91,   30,  391,  109,  113,  391,    0,   95,   33,   99,
       34,  391,    0,   35,  391,  100,    0,   43,  391,   99,
        0,   46,  391,   97,    0,   99,   95,   76,   87,  391,
       74,   72,   71,  391,   68,  391,   74,    0,    0,    0,
        0,   69,   75,   73,   89,   13,  391,   33,   41,   30,
       25,   85,   86,  391,  391,  299,  307,  315,  323,  331,

      339,    5,  346,  353,  360,  367,  374,  382
    } ;

static const flex_int16_t yy_def[109] =
    {   0,
       96,   96,   95,    3,   97,   97,   98,   98,   99,   99,
      100,  100,   95,   95,   95,   95,   95,   95,  101,  102,
       95,  103,  104,  104,   95,   95,  104,  105,  105,   95,
       95,  105,  106,  106,   95,   95,  106,  107,  108,  107,
      107,   95,   95,   95,  101,   95,  102,   95,   95,   95,
      103,   95,  104,   95,   95,  104,  105,   95,   95,  105,
      106,   95,   95,  106,  107,  108,  107,   95,   95,   95,
      104,  105,  106,   95,  107,   95,   95,  104,  105,  106,
      107,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,    0,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95
    } ;

static const flex_int16_t yy_nxt[420] =
    {   0,
       95,   15,   16,   15,   42,   43,   42,   49,   54,   55,
       54,   47,   50,   95,   86,   52,   58,   59,   58,   62,
       63,   62,   87,   17,   42,   43,   42,   18,   15,   16,
       15,   42,   43,   42,   49,   49,   54,   55,   54,   50,
       50,   92,   52,   52,   58,   59,   58,   62,   63,   62,
       17,   91,   90,   89,   18,   14,   15,   16,   15,   14,
       19,   14,   20,   20,   14,   21,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   17,   22,
       22,   22,   18,   24,   25,   24,   93,   93,   85,   84,
       86,   83,   82,   81,   94,   94,   80,   79,   87,   78,

       77,   76,   75,   74,   73,   26,   72,   71,   70,   27,
       24,   25,   24,   88,   69,   46,   68,   67,   64,   60,
       56,   48,   46,   44,   95,   95,   95,   95,   95,   95,
       95,   95,   26,   95,   95,   95,   27,   29,   30,   29,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   31,
       95,   95,   95,   32,   29,   30,   29,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   31,   95,   95,   95,
       32,   34,   35,   34,   95,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   36,   95,   95,   95,   37,   34,   35,
       34,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       36,   95,   95,   95,   37,   15,   16,   15,   39,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   40,   95,   95,
       95,   41,   15,   16,   15,   39,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   40,   95,   95,   95,   41,   14,

       14,   14,   14,   14,   14,   14,   14,   23,   23,   23,
       23,   23,   23,   23,   23,   28,   28,   28,   28,   28,
       28,   28,   28,   33,   33,   33,   33,   33,   33,   33,
       33,   38,   38,   38,   38,   38,   38,   38,   38,   45,
       45,   45,   45,   45,   45,   45,   45,   51,   95,   95,
       95,   51,   51,   53,   53,   95,   53,   53,   53,   53,
       57,   57,   95,   57,   57,   57,   57,   61,   61,   95,
       61,   61,   61,   61,   65,   95,   95,   95,   95,   65,
       65,   65,   66,   66,   95,   66,   95,   66,   66,   66,
       13,   95,   95,   95,   95,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95
    } ;

static const flex_int16_t yy_chk[420] =
    {   0,
        0,    1,    1,    1,   17,   17,   17,   22,   26,   26,
       26,  102,   22,    0,   86,   22,   31,   31,   31,   36,
       36,   36,   86,    1,   40,   40,   40,    1,    2,    2,
        2,   42,   42,   42,   49,   51,   54,   54,   54,   49,
       51,   91,   49,   51,   58,   58,   58,   62,   62,   62,
        2,   90,   89,   88,    2,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    5,    5,    5,   92,   93,   84,   83,
       85,   82,   77,   75,   92,   93,   73,   72,   85,   71,

       69,   68,   67,   66,   64,    5,   60,   56,   50,    5,
        6,    6,    6,   85,   48,   45,   44,   41,   37,   32,
       27,   21,   19,   18,   13,    0,    0,    0,    0,    0,
        0,    0,    6,    0,    0,    0,    6,    7,    7,    7,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    7,
        0,    0,    0,    7,    8,    8,    8,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    8,    0,    0,    0,
        8,    9,    9,    9,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    9,    0,    0,    0,    9,   10,   10,
       10,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       10,    0,    0,    0,   10,   11,   11,   11,   11,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   11,    0,    0,
        0,   11,   12,   12,   12,   12,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   12,    0,    0,    0,   12,   96,

       96,   96,   96,   96,   96,   96,   96,   97,   97,   97,
       97,   97,   97,   97,   97,   98,   98,   98,   98,   98,
       98,   98,   98,   99,   99,   99,   99,   99,   99,   99,
       99,  100,  100,  100,  100,  100,  100,  100,  100,  101,
      101,  101,  101,  101,  101,  101,  101,  103,    0,    0,
        0,  103,  103,  104,  104,    0,  104,  104,  104,  104,
      105,  105,    0,  105,  105,  105,  105,  106,  106,    0,
      106,  106,  106,  106,  107,    0,    0,    0,    0,  107,
      107,  107,  108,  108,    0,  108,    0,  108,  108,  108,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[26] =
    {   0,
0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 
    0, 1, 0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
/******************************************************************************
 *
 * Copyright (C) 1997-2019 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby
 * granted. No representations are made about the suitability of this software
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 */

#line 20 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"

/*
 * includes
 */
#include "config.h"
#include "input.h"
#include "inputbool.h"
#include "inputstring.h"
#include "inputobsolete.h"
#include "config_msg.h"

#include <QString>
#include <QVariant>
#include <QStack>
#include <QByteArray>
#include <QFileInfo>
#include <QStringList>
#include <QRegularExpression>
#include <QTextStream>
#include <QMessageBox>

#define YY_NO_UNISTD_H 1

#define MAX_INCLUDE_DEPTH 10

#define USE_STATE2STRING 0

/* -----------------------------------------------------------------
 *
 * static variables
 */

struct ConfigFileState
{
  int lineNr;
  FILE *file;
  YY_BUFFER_STATE oldState;
  YY_BUFFER_STATE newState;
  QString fileName;
};

static const QHash<QString,Input*>   *g_options=nullptr;
static FILE                          *g_file=nullptr;
static QString                        g_yyFileName;
static QString                        g_includeName;
static QVariant                       g_includePathList;
static QStack<ConfigFileState*>       g_includeStack;
static int                            g_includeDepth=0;
static QVariant                      *g_arg=nullptr;
static Input                         *g_curOption=nullptr;
static QByteArray                     g_str;
static std::unique_ptr<TextCodecAdapter> g_codec = std::make_unique<TextCodecAdapter>("UTF-8");
static QString                        g_codecName = QString::fromLatin1("UTF-8");
static QString                        g_cmd;
static bool                           g_isEnum=false;

static const char *stateToString(int state);

/* -----------------------------------------------------------------
 */
#undef  YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(buf,max_size);

static int yyread(char *buf,int maxSize)
{
    // no file included
    if (g_includeStack.isEmpty())
    {
      return static_cast<int>(fread(buf,1,maxSize,g_file));
    }
    else
    {
      return static_cast<int>(fread(buf,1,maxSize,g_includeStack.top()->file));
    }
}

static void substEnvVarsInStrList(QStringList &sl);
static void substEnvVarsInString(QString &s);

static void checkEncoding()
{
  Input *option = g_options->value(QString::fromLatin1("DOXYFILE_ENCODING"));
  if (option && option->value().toString()!=g_codecName)
  {
    auto newCodec = std::make_unique<TextCodecAdapter>(option->value().toString().toLatin1());
    if (newCodec->isValid())
    {
      g_codec.swap(newCodec);
      g_codecName = option->value().toString();
    }
  }
}

static QByteArray stripComment(const QByteArray &s)
{
  // check if there is a comment at the end of the string
  bool insideQuote=false;
  int l = s.length();
  for (int i=0;i<l;i++)
  {
    char c = s.at(i);
    if (c=='\\') // skip over escaped characters
    {
      i++;
    }
    else if (c=='"') // toggle inside/outside quotation
    {
      insideQuote=!insideQuote;
    }
    else if (!insideQuote && c=='#') // found start of a comment
    {
      return s.left(i).trimmed();
    }
  }
  return s;
}


static void processString()
{
  // strip leading and trailing whitespace
  QByteArray s = stripComment(g_str.trimmed());
  int l = s.length();

  // remove surrounding quotes if present (and not escaped)
  if (l>=2 && s.at(0)=='"' && s.at(l-1)=='"' && // remove quotes
      (s.at(l-2)!='\\' || (s.at(l-2)=='\\' && s.at(l-3)=='\\')))
  {
    s=s.mid(1,s.length()-2);
    l=s.length();
  }

  // check for invalid and/or escaped quotes
  bool warned=false;
  QByteArray result;
  for (int i=0;i<l;i++)
  {
    char c = s.at(i);
    if (c=='\\') // escaped character
    {
      if (i<l-1 && s.at(i+1)=='"') // unescape the quote character
      {
        result+='"';
      }
      else // keep other escaped characters in escaped form
      {
        result+=c;
        if (i<l-1)
        {
          result+=s.at(i+1);
        }
      }
      i++; // skip over the escaped character
    }
    else if (c=='"') // unescaped quote
    {
      if (!warned)
      {
        std::string str = g_str.trimmed().data();
        config_warn("Invalid value for '%s' tag at line %d, file %s: Value '%s' is not properly quoted\n",
                    qPrintable(g_cmd),yylineno-1,qPrintable(g_yyFileName),str.c_str());
      }
      warned=true;
    }
    else // normal character
    {
      result+=c;
    }
  }

  // recode the string
  if (g_isEnum)
  {
    InputString *cur = dynamic_cast<InputString *>(g_curOption);
    *g_arg = cur->checkEnumVal(g_codec->decode(result));
  }
  else
  {
    *g_arg = QVariant(g_codec->decode(result));
  }

  // update encoding
  checkEncoding();

  //printf("Processed string '%s'\n",g_string->data());
}

static void processList()
{
  bool allowCommaAsSeparator = g_cmd!=QString::fromLatin1("PREDEFINED");

  const QByteArray s = stripComment(g_str.trimmed());
  int l = s.length();

  QByteArray elemStr;

  // helper to push elemStr to the list and clear it
  auto addElem = [&elemStr]()
  {
    if (!elemStr.isEmpty())
    {
      //printf("Processed list element '%s'\n",e.data());
      *g_arg = QVariant(g_arg->toStringList() << g_codec->decode(elemStr));
      elemStr="";
    }
  };

  bool needsSeparator=false;
  int insideQuote=false;
  bool warned=false;
  for (int i=0;i<l;i++)
  {
    char c = s.at(i);
    if (!needsSeparator && c=='\\') // escaped character
    {
      if (i<l-1 && s.at(i+1)=='"') // unescape the quote character
      {
        elemStr+='"';
      }
      else if (insideQuote && i<l-2 && s.at(i+1)=='\\' && s.at(i+2)=='"') // escaped "\" at the end of a quoted section
      {
        elemStr+="\\";
      }
      else // keep other escaped characters in escaped form
      {
        elemStr+=c;
        if (i<l-1)
        {
          elemStr+=s.at(i+1);
        }
      }
      i++; // skip over the escaped character
    }
    else if (!needsSeparator && c=='"') // quote character
    {
      if (!insideQuote)
      {
        insideQuote=true;
      }
      else // this quote ends an element
      {
        insideQuote=false;
        needsSeparator=true;
      }
    }
    else if (!insideQuote && ((c==',' && allowCommaAsSeparator) || isspace(c))) // separator
    {
      needsSeparator=false;
      addElem();
    }
    else // normal content character
    {
      if (needsSeparator)
      {
        if (!warned)
        {
          std::string str = g_str.trimmed().data();
          config_warn("Invalid value for '%s' tag at line %d, file %s: Values in list '%s' are not properly space %sseparated\n",
                    qPrintable(g_cmd),yylineno-1,qPrintable(g_yyFileName),str.c_str(),allowCommaAsSeparator?"or comma ":"");
          warned=true;
        }
        needsSeparator=false;
        i--; // try the character again as part of a new element
        addElem();
      }
      else
      {
        elemStr+=c;
      }
    }
  }
  // add last part
  addElem();
  if (insideQuote)
  {
    std::string str = g_str.trimmed().data();
    config_warn("Invalid value for '%s' tag at line %d, file %s: Values in list '%s' are not properly quoted\n",
                qPrintable(g_cmd),yylineno-1,qPrintable(g_yyFileName),str.c_str());
  }
}


static FILE *tryPath(const QString &path,const QString &fileName)
{
  QString absName=!path.isEmpty() ? path+QString::fromLatin1("/")+fileName : fileName;
  QFileInfo fi(absName);
  if (fi.exists() && fi.isFile())
  {
    FILE *f = fopen(absName.toLocal8Bit(),"r");
    if (f==nullptr)
      config_err("could not open file %s for reading\n",qPrintable(absName));
    else
      return f;
  }
  return nullptr;
}

static FILE *findFile(const QString &fileName)
{
  if (QFileInfo(fileName).isAbsolute()) // absolute path
  {
    return tryPath(QString(), fileName);
  }

  // relative path, try with include paths in the list
  QStringList sl = g_includePathList.toStringList();
  substEnvVarsInStrList(sl);
  foreach (QString s, sl)
  {
    FILE *f = tryPath(s,fileName);
    if (f) return f;
  }
  // try cwd if g_includePathList fails
  return tryPath(QString::fromLatin1("."),fileName);
}

static void readIncludeFile(const QString &incName)
{
  if (g_includeDepth==MAX_INCLUDE_DEPTH)
  {
    config_err("maximum include depth (%d) reached, %s is not included.",
               MAX_INCLUDE_DEPTH,qPrintable(incName));
  }

  QString inc = incName;
  substEnvVarsInString(inc);
  inc = inc.trimmed();
  uint incLen = inc.length();
  if (inc.at(0)==QChar::fromLatin1('"') &&
      inc.at(incLen-1)==QChar::fromLatin1('"')) // strip quotes
  {
    inc=inc.mid(1,incLen-2);
  }

  FILE *f = findFile(inc);
  if (f) // see if the include file can be found
  {
    // For debugging
#if SHOW_INCLUDES
    for (i=0;i<includeStack.count();i++) msg("  ");
    msg("@INCLUDE = %s: parsing...\n",qPrintable(inc));
#endif

    // store the state of the old file
    ConfigFileState *fs=new ConfigFileState;
    fs->oldState=YY_CURRENT_BUFFER;
    fs->fileName=g_yyFileName;
    fs->file=f;
    // push the state on the stack
    g_includeStack.push(fs);
    // set the scanner to the include file
    yy_switch_to_buffer(yy_create_buffer(f, YY_BUF_SIZE));
    fs->newState=YY_CURRENT_BUFFER;
    g_yyFileName=inc;
    g_includeDepth++;
  }
  else
  {
    config_err("@INCLUDE = %s: not found!\n",qPrintable(inc));
  }
}

#if USE_STATE2STRING
static const char *stateToString(int state);
#endif

#line 1232 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"

#line 1234 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"

#define INITIAL 0
#define Start 1
#define SkipInvalid 2
#define GetString 3
#define GetStrList 4
#define Include 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 398 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"


#line 1457 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 96 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 95 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 400 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"

	YY_BREAK
/*-------------- Comments ---------------*/
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 404 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ /* Skip comment */ }
	YY_BREAK
/*-------------- TAG start ---------------*/
case 3:
YY_RULE_SETUP
#line 408 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{
                                           g_cmd = g_codec->decode(yytext);
                                           g_cmd=g_cmd.left(g_cmd.length()-1).trimmed();
					   g_curOption = g_options->value(g_cmd);
					   if (g_curOption==nullptr) // oops not known
					   {
					     config_warn("ignoring unsupported tag '%s' at line %d, file %s\n",
						 qPrintable(g_cmd),yylineno,qPrintable(g_yyFileName));
					     BEGIN(SkipInvalid);
					   }
					   else // known tag
					   {
					     g_arg = &g_curOption->value();
                                             g_str = QByteArray();
                                             g_isEnum = false;
					     switch(g_curOption->kind())
					     {
					       case Input::StrList:
						 *g_arg = QStringList();
					         BEGIN(GetStrList);
					         break;
					       case Input::String:
                                                 g_isEnum = dynamic_cast<InputString *>(g_curOption)->stringMode() == InputString::StringFixed;
                                                 BEGIN(GetString);
					         break;
					       case Input::Int:
					         BEGIN(GetString);
					         break;
					       case Input::Bool:
					         BEGIN(GetString);
						 break;
					       case Input::Obsolete:
                                                 {
                                                   config_warn("Tag '%s' at line %d of file %s has become obsolete.\n"
                                                       "To avoid this warning please update your configuration "
                                                       "file using \"doxygen -u\"\n", qPrintable(g_cmd),
                                                       yylineno,qPrintable(g_yyFileName));
                                                   InputObsolete *obsoleteOpt = dynamic_cast<InputObsolete*>(g_curOption);
                                                   if (obsoleteOpt)
                                                   {
                                                     if (obsoleteOpt->orgKind()==Input::StrList)
                                                     {
                                                       *g_arg = QStringList();
                                                       BEGIN(GetStrList);
                                                     }
                                                     else
                                                     {
                                                       BEGIN(GetString);
                                                     }
                                                   }
                                                   else
                                                   {
                                                     BEGIN(SkipInvalid);
                                                   }
                                                 }
						 break;
					     }
					   }
					}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 467 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{
                                          g_cmd=g_codec->decode(yytext);
                                          g_cmd=g_cmd.left(g_cmd.length()-2).trimmed();
					  g_curOption = g_options->value(g_cmd);
					  if (g_curOption==nullptr) // oops not known
					  {
					    config_warn("ignoring unsupported tag '%s' at line %d, file %s\n",
						yytext,yylineno,qPrintable(g_yyFileName));
					    BEGIN(SkipInvalid);
					  }
					  else // known tag
					  {
					    switch(g_curOption->kind())
					    {
					      case Input::StrList:
						g_arg = &g_curOption->value();
						g_str=QByteArray();
					        BEGIN(GetStrList);
					        break;
					      case Input::String:
					      case Input::Int:
					      case Input::Bool:
					        config_warn("operator += not supported for '%s'. Ignoring line %d, file %s\n",
						    qPrintable(g_cmd),yylineno,qPrintable(g_yyFileName));
					        BEGIN(SkipInvalid);
						break;
					      case Input::Obsolete:
                                                {
					          config_warn("Tag '%s' at line %d of file %s has become obsolete.\n"
						              "To avoid this warning please update your configuration "
						  	      "file using \"doxygen -u\"\n",
							      qPrintable(g_cmd),yylineno,qPrintable(g_yyFileName));
                                                   InputObsolete *obsoleteOpt = dynamic_cast<InputObsolete*>(g_curOption);
                                                   if (obsoleteOpt && obsoleteOpt->orgKind()==Input::StrList)
                                                   {
						     g_arg = &g_curOption->value();
						     g_str=QByteArray();
                                                     BEGIN(GetStrList);
                                                   }
					           else
                                                   {
                                                     BEGIN(SkipInvalid);
                                                   }
                                                }
					        break;
					     }
					   }
					}
	YY_BREAK
/*-------------- INCLUDE* ---------------*/
case 5:
YY_RULE_SETUP
#line 518 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ BEGIN(GetStrList); g_arg=&g_includePathList; *g_arg = QStringList(); g_str=QByteArray(); }
	YY_BREAK
/* include a config file */
case 6:
YY_RULE_SETUP
#line 520 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ BEGIN(Include);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 521 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{
  					  readIncludeFile(g_codec->decode(yytext));
  					  BEGIN(Start);
					}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(Start):
case YY_STATE_EOF(SkipInvalid):
case YY_STATE_EOF(GetString):
case YY_STATE_EOF(GetStrList):
case YY_STATE_EOF(Include):
#line 525 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{
                                          //printf("End of include file\n");
					  //printf("Include stack depth=%d\n",g_includeStack.count());
                                          if (g_includeStack.isEmpty())
					  {
					    //printf("Terminating scanner!\n");
					    yyterminate();
					  }
					  else
					  {
					    ConfigFileState *fs = g_includeStack.pop();
					    fclose(fs->file);
					    YY_BUFFER_STATE oldBuf = YY_CURRENT_BUFFER;
					    yy_switch_to_buffer( fs->oldState );
					    yy_delete_buffer( oldBuf );
					    g_yyFileName=fs->fileName;
					    delete fs;
                                            g_includeDepth--;
					  }
  					}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 546 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ config_warn("ignoring unknown tag '%s' at line %d, file %s\n",yytext,yylineno,qPrintable(g_yyFileName)); }
	YY_BREAK
/*-------------- GetString ---------------*/
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 550 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // end of string
                                          processString();
                                          BEGIN(Start);
                                        }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 554 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // line continuation
                                          g_str+=' ';
                                        }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 557 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // escape character
                                          g_str+=yytext;
                                        }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 560 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // string part without escape characters
                                          g_str+=yytext;
                                        }
	YY_BREAK
/*-------------- GetStrList ---------------*/
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 566 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // end of list
                                          processList();
                                          BEGIN(Start);
                                        }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 570 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // line continuation
                                          g_str+=' ';
                                        }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 573 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // escape character
                                          g_str+=yytext;
                                        }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 576 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // string part without escape characters
                                          g_str+=yytext;
                                        }
	YY_BREAK
/*-------------- SkipInvalid ---------------*/
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 582 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // end of skipped part
                                          BEGIN(Start);
                                        }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 585 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // line continuation
                                          g_str+=' ';
                                        }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 588 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // escape character
                                          g_str+=yytext;
                                        }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 591 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ // string part without escape characters
                                          g_str+=yytext;
                                        }
	YY_BREAK
/*-------------- fall through -------------*/
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 597 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 598 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ }
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 599 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"

	YY_BREAK
case 24:
YY_RULE_SETUP
#line 600 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
{ config_warn("ignoring unknown character '%c' at line %d, file %s\n",yytext[0],yylineno,qPrintable(g_yyFileName)); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 602 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"
ECHO;
	YY_BREAK
#line 1824 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw_intermediate.cpp"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 28);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 96 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 28;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 96 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 95);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 602 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/build/generated_src/doxywizard/config_doxyw.l"


/*@ ----------------------------------------------------------------------------
 */

static void substEnvVarsInString(QString &s)
{
  static QRegularExpression re(QString::fromLatin1("\\$\\([a-z_A-Z0-9]+\\)"));
  if (s.isEmpty()) return;
  int p=0;
  int i,l;
  //printf("substEnvVarInString(%s) start\n",qPrintable(s));

  QRegularExpressionMatch match;
  while ((i=s.indexOf(re,p,&match))!=-1)
  {
    l = match.capturedLength();
    //printf("Found environment var s.mid(%d,%d)='%s'\n",i+2,l-3,qPrintable(s.mid(i+2,l-3)));
    QString env=g_codec->decode(getenv(s.mid(i+2,l-3).toLatin1()));
    substEnvVarsInString(env); // recursively expand variables if needed.
    s = s.left(i)+env+s.right(s.length()-i-l);
    p=i+env.length(); // next time start at the end of the expanded string
  }
  s=s.trimmed(); // to strip the bogus space that was added when an argument
                         // has quotes
  //printf("substEnvVarInString(%s) end\n",qPrintable(s));
}

static void substEnvVarsInStrList(QStringList &sl)
{
  QStringList out;

  foreach (QString result, sl)
  {
    // an argument with quotes will have an extra space at the end, so wasQuoted will be true.
    bool wasQuoted = (result.indexOf(QChar::fromLatin1(' '))!=-1) ||
                     (result.indexOf(QChar::fromLatin1('\t'))!=-1);
    // here we strip the quote again
    substEnvVarsInString(result);

    //printf("Result %s was quoted=%d\n",qPrintable(result),wasQuoted);

    if (!wasQuoted) /* as a result of the expansion, a single string
		       may have expanded into a list, which we'll
		       add to sl. If the original string already
		       contained multiple elements no further
		       splitting is done to allow quoted items with spaces! */
    {
      int l=result.length();
      int i,p=0;
      // skip spaces
      // search for a "word"
      for (i=0;i<l;i++)
      {
	QChar c;
	// skip until start of new word
	while (i<l && ((c=result.at(i))==QChar::fromLatin1(' ') || c==QChar::fromLatin1('\t'))) i++;
	p=i; // p marks the start index of the word
	// skip until end of a word
	while (i<l && ((c=result.at(i))!=QChar::fromLatin1(' ') &&
	              c!=QChar::fromLatin1('\t') &&
		      c!=QChar::fromLatin1('"'))) i++;
	if (i<l) // not at the end of the string
	{
	  if (c==QChar::fromLatin1('"')) // word within quotes
	  {
	    p=i+1;
	    for (i++;i<l;i++)
	    {
	      c=result.at(i);
	      if (c==QChar::fromLatin1('"')) // end quote
	      {
                out += result.mid(p,i-p);
		p=i+1;
		break;
	      }
	      else if (c==QChar::fromLatin1('\\')) // skip escaped stuff
	      {
		i++;
	      }
	    }
	  }
	  else if (c==QChar::fromLatin1(' ') || c==QChar::fromLatin1('\t')) // separator
	  {
            out += result.mid(p,i-p);
	    p=i+1;
	  }
	}
      }
      if (p!=l) // add the leftover as a string
      {
        out += result.right(l-p);
      }
    }
    else // just goto the next element in the list
    {
      out += result;
    }
  }
  sl = out;
}

//--------------------------------------------------------------------------

inline bool qisspace(char c)
{
  return c==' ' || c=='\t' || c=='\n' || c=='\r';
} 

// Returns a quoted copy of this string, unless it is already quoted.
// Note that trailing and leading whitespace is removed.
QString quoted(QString &inpValue)
{
  std::string rep =  inpValue.toStdString();
  size_t start=0, sl=rep.size(), end=sl-1;
  while (start<sl  && qisspace(rep[start])) start++; // skip over leading whitespace
  if (start==sl) return QString(); // only whitespace
  while (end>start && qisspace(rep[end]))   end--;   // skip over trailing whitespace
  bool needsQuotes=false;
  size_t i=start;
  if (i<end && rep[i]!='"') // stripped string has at least non-whitespace unquoted character
  {
    while (i<end && !needsQuotes) // check if the to be quoted part has at least one whitespace character
    {
      needsQuotes = rep[i] =='-';
      needsQuotes |= qisspace(rep[i++]);
    }
  }
  std::string  result = rep.substr(start,1+end-start);
  if (needsQuotes)
  {
    result = "\"" + result + "\"";
  }
  return QString::fromUtf8(result.c_str());
}

static void updateAttribute(InputString *attr, const char *key, QString &inpValue)
{
  QString attrValue = attr->value().toString();
  std::string s = attrValue.toStdString();
  // look for key\s*=
  QRegularExpression re(QString::fromLatin1(key)+QString::fromLatin1(R"(\s*=)"));
  QRegularExpressionMatch match = re.match(attrValue);
  if (match.hasMatch()) // replace existing attribute
  {
    size_t len      = s.length();
    size_t startPos = match.capturedStart()+match.capturedLength(); // position after =
    size_t pos      = startPos;
    while (pos<len && qisspace(s[pos])) pos++;
    if (pos<len && s[pos]=='"') // quoted value, search for end quote, ignoring escaped quotes
    {
      char pc=s[pos];
      pos++; // skip over start quote
      while (pos<len && (s[pos]!='"' || (s[pos]=='"' && pc=='\\'))) pc=s[pos++];
      if (pos<len) pos++; // skip over end quote
    }
    else // unquoted value, search for attribute separator (space,comma, or semicolon)
    {
      while (pos<len && s[pos]!=',' && s[pos]!=';' && !qisspace(s[pos])) pos++;
    }
    QString value;
    if (inpValue.isEmpty())
    {
      value = attrValue.mid(startPos,pos-startPos);
    }
    else
    {
      value = inpValue;
    }
    // pos is now the position after the value, so replace the part between [start..pos) with the new value
    attrValue=attrValue.left(startPos)+quoted(value)+attrValue.mid(pos);
  }
  else // append new attribute
  {
    if (!inpValue.isEmpty())
    {
      if (!attrValue.isEmpty()) attrValue+=QString::fromLatin1(",");
      attrValue+=QString::fromLatin1(key)+QString::fromLatin1("=")+quoted(inpValue);
    }
  }
  attr->setValue(attrValue);
}

static void upgradeConfig(const QHash<QString,Input*> &options)
{
  // check for presence of obsolete CLASS_DIAGRAM option and correct CLASS_GRAPH if needed
  auto it1 = options.find(QString::fromLatin1("CLASS_DIAGRAMS"));
  auto it2 = options.find(QString::fromLatin1("HAVE_DOT"));
  auto it3 = options.find(QString::fromLatin1("CLASS_GRAPH"));
  if (it1!=options.end() && it2!=options.end() && it3!=options.end())
  {
    if ((*it1)->kind()==Input::Obsolete)
    {
      InputObsolete *optClassDiagram = dynamic_cast<InputObsolete*>(*it1);
      InputBool     *optHaveDot      = dynamic_cast<InputBool*>    (*it2);
      InputString   *optClassGraph   = dynamic_cast<InputString*>  (*it3);
      if (optClassDiagram->orgKind()==Input::Bool)
      {
        const QVariant &v1 = optClassDiagram->value();
        const QVariant &v2 = optHaveDot->value();
        QVariant &v3 = optClassGraph->value();
        bool isValid1=false,isValid2=false,isValid3=false;
        bool classDiagrams = InputBool::convertToBool(v1,isValid1);
        bool haveDot       = InputBool::convertToBool(v2,isValid2);
        bool classGraph    = InputBool::convertToBool(v3,isValid3);
        if (isValid1 && isValid2 && isValid3 && !classDiagrams && !haveDot && classGraph)
        {
          config_warn("Changing CLASS_GRAPH option to TEXT because obsolete option CLASS_DIAGRAM was found and set to NO.\n");
          optClassGraph->setValue(QString::fromLatin1("TEXT"));
        }
      }
    }
  }

  // update TIMESTAMP based on HTML_TIMESTAMP and LATEX_TIMESTAMP
  auto HtmlTimestamp = options.find(QString::fromLatin1("HTML_TIMESTAMP"));
  auto timestamp     = options.find(QString::fromLatin1("TIMESTAMP"));
  if (HtmlTimestamp!=options.end() && timestamp!=options.end())
  {
    if ((*HtmlTimestamp)->kind()==Input::Obsolete)
    {
      InputObsolete *htmlTimestamp_ = dynamic_cast<InputObsolete*>(*HtmlTimestamp);
      InputString   *timestamp_ = dynamic_cast<InputString*>(*timestamp);
      if (htmlTimestamp_->orgKind()==Input::Bool)
      {
        const QVariant &htmlTimestampValue = htmlTimestamp_->value();
        bool isValid = false;
        bool bTimestamp = InputBool::convertToBool(htmlTimestampValue,isValid);
        if (isValid && bTimestamp)
        {
          config_warn("Changing TIMESTAMP option to YES because obsolete option HTML_TIMESTAMP was found and was set to YES.\n");
          timestamp_->setValue(QString::fromLatin1("YES"));
        }
      }
    }
  }

  auto LatexTimestamp = options.find(QString::fromLatin1("LATEX_TIMESTAMP"));
  if (LatexTimestamp!=options.end() && timestamp!=options.end())
  {
    if ((*LatexTimestamp)->kind()==Input::Obsolete)
    {
      InputObsolete *latexTimestamp_ = dynamic_cast<InputObsolete*>(*LatexTimestamp);
      InputString   *timestamp_ = dynamic_cast<InputString*>(*timestamp);
      if (latexTimestamp_->orgKind()==Input::Bool)
      {
        const QVariant &latexTimestampValue = latexTimestamp_->value();
        bool isValid = false;
        bool bTimestamp = InputBool::convertToBool(latexTimestampValue,isValid);
        if (isValid && bTimestamp)
        {
          config_warn("Changing TIMESTAMP option to YES because obsolete option LATEX_TIMESTAMP was found and was set to YES.\n");
          timestamp_->setValue(QString::fromLatin1("YES"));
        }
      }
    }
  }

  auto fontName = options.find(QString::fromLatin1("DOT_FONTNAME"));
  auto fontSize = options.find(QString::fromLatin1("DOT_FONTSIZE"));
  QString fontNameValue;
  QString fontSizeValue;
  // correct DOT_FONTNAME if needed
  if (fontName!=options.end())
  {
    if ((*fontName)->kind()==Input::Obsolete)
    {
      InputObsolete *fontName_ = dynamic_cast<InputObsolete*>(*fontName);
      fontNameValue = fontName_->value().toString();
      if (fontNameValue == QString::fromLatin1("FreeSans") ||
          fontNameValue == QString::fromLatin1("FreeSans.ttf"))
      {
        config_warn("doxygen no longer ships with the FreeSans font.\n"
                    "  You may want to clear or change DOT_FONTNAME.\n"
                    "  Otherwise you run the risk that the wrong font is being used for dot generated graphs.\n");
      }
    }
  }

  if (fontSize!=options.end())
  {
    if ((*fontSize)->kind()==Input::Obsolete)
    {
      InputObsolete *fontSize_ = dynamic_cast<InputObsolete*>(*fontSize);
      fontSizeValue = fontSize_->value().toString();
    }
  }

  if (fontName!=options.end() || fontSize!=options.end())
  {
    auto commonAttrOpt = options.find(QString::fromLatin1("DOT_COMMON_ATTR"));
    auto edgeAttrOpt = options.find(QString::fromLatin1("DOT_EDGE_ATTR"));
    if ((*commonAttrOpt)->kind()==Input::String)
    {
      QString commonAttrValue;
      InputString *commonAttr_ = dynamic_cast<InputString*>(*commonAttrOpt);
      if ((*commonAttr_).stringMode()==InputString::StringFree)
      {
        if (fontName!=options.end())
        {
          updateAttribute(commonAttr_, "fontname", fontNameValue);
        }
        if (fontSize!=options.end())
        {
          updateAttribute(commonAttr_, "fontsize", fontSizeValue);
        }
      }
    }
    if ((*edgeAttrOpt)->kind()==Input::String)
    {
      QString edgeAttrValue;
      InputString *edgeAttr_ = dynamic_cast<InputString*>(*edgeAttrOpt);
      if ((*edgeAttr_).stringMode()==InputString::StringFree)
      {
        if (fontName!=options.end())
        {
          updateAttribute(edgeAttr_, "labelfontname", fontNameValue);
        }
        if (fontSize!=options.end())
        {
          updateAttribute(edgeAttr_, "labelfontsize", fontSizeValue);
        }
      }
    }
  }
}

//--------------------------------------------------------------------------

bool parseConfig(
      const QString &fileName,
      const QHash<QString,Input *> &options
    )
{
  yylineno = 1;
  config_open();
  QHashIterator<QString, Input*> i(options);
  g_file = fopen(fileName.toLocal8Bit(),"r");
  if (g_file==nullptr) return false;

  // reset all values
  i.toFront();
  while (i.hasNext())
  {
    i.next();
    if (i.value())
    {
      i.value()->reset();
    }
  }

  // parse config file
  g_options       = &options;
  g_yyFileName    = fileName;
  g_includeStack.clear();
  g_includeDepth  = 0;
  config_doxywYYrestart( config_doxywYYin );
  BEGIN( Start );
  config_doxywYYlex();

  upgradeConfig(options);

  // update the values in the UI
  i.toFront();
  while (i.hasNext())
  {
    i.next();
    if (i.value())
    {
      //printf("Updating: %s\n",qPrintable(i.key()));
      i.value()->update();
    }
    else
    {
      printf("Invalid option: %s\n",qPrintable(i.key()));
    }
  }
  fclose(g_file);
  config_finish();
  return true;
}

void writeStringValue(QTextStream &t,TextCodecAdapter *codec,const QString &s,bool convert)
{
  QChar c;
  bool needsEscaping=false;
  bool needsHashEscaping=false;
  // convert the string back to it original encoding
  codec->applyToStream(t);
  const QChar *p=s.data();
  if (!s.isEmpty() && !p->isNull())
  {
    if (*p != QChar::fromLatin1('"'))
    {
      while (!(c=*p++).isNull() && !needsEscaping)
      {
        needsEscaping = (c==QChar::fromLatin1(' ')  ||
                         c==QChar::fromLatin1(',')  ||
                         c==QChar::fromLatin1('\n') ||
                         c==QChar::fromLatin1('\t') ||
                         c==QChar::fromLatin1('\\') ||
                         c==QChar::fromLatin1('"'));
      }
      p=s.data();
      while (!(c=*p++).isNull() && !needsHashEscaping)
      {
        needsHashEscaping = (c==QChar::fromLatin1('#'));
      }
    }
    if (needsHashEscaping || needsEscaping)
    {
      t << "\"";
    }
    if (needsEscaping)
    {
      p=s.data();
      while (!p->isNull())
      {
        if (*p   ==QChar::fromLatin1(' ') &&
           *(p+1)==QChar::fromLatin1('\0')) break; // skip inserted space at the end
        if (*p   ==QChar::fromLatin1('"')) t << "\\"; // escape quotes
        if (*p   ==QChar::fromLatin1('\\') && (p+1)->isNull()) t << "\\"; // escape last "\", for e.g c:\temp\ where "\" is part of the path
        if (convert)
        {
          if (*p   ==QChar::fromLatin1('<')) t << "&lt;";
          else if (*p   ==QChar::fromLatin1('>')) t << "&gt;";
          else if (*p   ==QChar::fromLatin1('&')) t << "&amp;";
          else t << *p;
        }
        else
        {
          t << *p;
        }
        p++;
      }
    }
    else
    {
      p=s.data();
      while (!p->isNull())
      {
        if (convert)
        {
          if (*p   ==QChar::fromLatin1('<')) t << "&lt;";
          else if (*p   ==QChar::fromLatin1('>')) t << "&gt;";
          else if (*p   ==QChar::fromLatin1('&')) t << "&amp;";
          else t << *p;
        }
        else
        {
          t << *p;
        }
        p++;
      }
    }
    if (needsHashEscaping || needsEscaping)
    {
      t << "\"";
    }
  }
}
#if USE_STATE2STRING
#include "config_doxyw.l.h"
#endif

